@@ -380,7 +380,7 @@ class VAEShell():
                     z[:,d] = torch.randn(size)
         return z
 
-    def greedy_decode(self, mem, src_mask=None):
+    def greedy_decode(self, mem, src_mask=None, condition=[]):
         """
         Greedy decode from model memory
 
@@ -394,7 +394,12 @@ class VAEShell():
         start_symbol = self.params['CHAR_DICT']['<start>']
         max_len = self.tgt_len
         decoded = torch.ones(mem.shape[0],1).fill_(start_symbol).long()
+        for tok in condition:
+            condition_symbol = self.params['CHAR_DICT'][tok]
+            condition_vec = torch.ones(mem.shape[0],1).fill_(condition_symbol).long()
+            decoded = torch.cat([decoded, condition_vec], dim=1)
         tgt = torch.ones(mem.shape[0],max_len+1).fill_(start_symbol).long()
+        tgt[:,:len(condition)+1] = decoded
         if src_mask is None and self.model_type == 'transformer':
             mask_lens = self.model.encoder.predict_mask_length(mem)
             src_mask = torch.zeros((mem.shape[0], 1, self.src_len+1))
@@ -410,7 +415,7 @@ class VAEShell():
             tgt = tgt.cuda()
 
         self.model.eval()
-        for i in range(max_len):
+        for i in range(len(condition), max_len):
             if self.model_type == 'transformer':
                 decode_mask = Variable(subsequent_mask(decoded.size(1)).long())
                 if self.use_gpu:
@@ -449,7 +454,7 @@ class VAEShell():
                                    token ids
             mems (np.array): Array of model memory vectors
         """
-        data = vae_data_gen(data, char_dict=self.params['CHAR_DICT'])
+        data = vae_data_gen(data, props=None, char_dict=self.params['CHAR_DICT'])
 
         data_iter = torch.utils.data.DataLoader(data,
                                                 batch_size=self.params['BATCH_SIZE'],
@@ -468,10 +473,13 @@ class VAEShell():
                 log_file.close()
             for i in range(self.params['BATCH_CHUNKS']):
                 batch_data = data[i*self.chunk_size:(i+1)*self.chunk_size,:]
+                mols_data = batch_data[:,:-1]
+                props_data = batch_data[:,-1]
                 if self.use_gpu:
-                    batch_data = batch_data.cuda()
+                    mols_data = mols_data.cuda()
+                    props_data = props_data.cuda()
 
-                src = Variable(batch_data).long()
+                src = Variable(mols_data).long()
                 src_mask = (src != self.pad_idx).unsqueeze(-2)
 
                 ### Run through encoder to get memory
@@ -490,7 +498,7 @@ class VAEShell():
                     decoded = None
 
                 if return_str:
-                    decoded = decode_smiles(decoded, self.params['ORG_DICT'])
+                    decoded = decode_mols(decoded, self.params['ORG_DICT'])
                     decoded_smiles += decoded
                 else:
                     decoded_smiles.append(decoded)
@@ -501,7 +509,8 @@ class VAEShell():
             return decoded_smiles
 
     def sample(self, n, method='greedy', sample_mode='rand',
-                        sample_dims=None, k=None, return_str=True):
+                        sample_dims=None, k=None, return_str=True,
+                        condition=[]):
         """
         Method for sampling from memory and decoding back into SMILES strings
 
@@ -527,12 +536,12 @@ class VAEShell():
 
         ### Decode logic
         if method == 'greedy':
-            decoded = self.greedy_decode(mem)
+            decoded = self.greedy_decode(mem, condition=condition)
         else:
             decoded = None
 
         if return_str:
-            decoded = decode_smiles(decoded, self.params['ORG_DICT'])
+            decoded = decode_mols(decoded, self.params['ORG_DICT'])
         return decoded
 
     def calc_mems(self, data, log=True, save_dir='memory', save_fn='model_name', save=True):
